__module_text_address() can be invoked within a RCU section, there is no
requirement to have preemption disabled.

Replace the preempt_disable() section around __module_text_address()
with RCU.

Cc: Huacai Chen <[email protected]>
Cc: Mark Rutland <[email protected]>
Cc: Masami Hiramatsu <[email protected]>
Cc: Steven Rostedt <[email protected]>
Cc: WANG Xuerui <[email protected]>
Cc: [email protected]
Cc: [email protected]
Acked-by: Peter Zijlstra (Intel) <[email protected]>
Signed-off-by: Sebastian Andrzej Siewior <[email protected]>
---
 arch/loongarch/kernel/ftrace_dyn.c | 9 ++++-----
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/arch/loongarch/kernel/ftrace_dyn.c 
b/arch/loongarch/kernel/ftrace_dyn.c
index 18056229e22e4..5b7b8ac13e350 100644
--- a/arch/loongarch/kernel/ftrace_dyn.c
+++ b/arch/loongarch/kernel/ftrace_dyn.c
@@ -85,14 +85,13 @@ static bool ftrace_find_callable_addr(struct dyn_ftrace 
*rec, struct module *mod
         * dealing with an out-of-range condition, we can assume it
         * is due to a module being loaded far away from the kernel.
         *
         * NOTE: __module_text_address() must be called with preemption
         * disabled, but we can rely on ftrace_lock to ensure that 'mod'
         * retains its validity throughout the remainder of this code.
         */
        if (!mod) {
-               preempt_disable();
-               mod = __module_text_address(pc);
-               preempt_enable();
+               scoped_guard(rcu)
+                       mod = __module_text_address(pc);
        }
 
        if (WARN_ON(!mod))
@@ -85,14 +85,13 @@ static bool ftrace_find_callable_addr(struct dyn_ftrace 
         * is due to a module being loaded far away from the kernel.
         *
-        * NOTE: __module_text_address() must be called with preemption
-        * disabled, but we can rely on ftrace_lock to ensure that 'mod'
+        * NOTE: __module_text_address() must be called within a RCU read
+        * section, but we can rely on ftrace_lock to ensure that 'mod'
         * retains its validity throughout the remainder of this code.
         */
-- 
2.47.1


Reply via email to